@@ -2,7 +2,7 @@
    nslcd.c - ldap local connection daemon
 
    Copyright (C) 2006 West Consulting
-   Copyright (C) 2006-2019 Arthur de Jong
+   Copyright (C) 2006-2025 Arthur de Jong
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -91,6 +91,12 @@ static int nslcd_nofork = 0;
 /* flag to indicate user requested the --check option */
 static int nslcd_checkonly = 0;
 
+/* name of the configuration file to load */
+static char *nslcd_conf_path = NSLCD_CONF_PATH;
+
+/* flag to indicate user requested the --test option */
+static int nslcd_testconfig = 0;
+
 /* the flag to indicate that a signal was received */
 static volatile int nslcd_receivedsignal = 0;
 
@@ -121,7 +127,7 @@ static void display_version(FILE *fp)
 {
   fprintf(fp, "%s\n", PACKAGE_STRING);
   fprintf(fp, "Written by Luke Howard and Arthur de Jong.\n\n");
-  fprintf(fp, "Copyright (C) 1997-2019 Arthur de Jong and others\n"
+  fprintf(fp, "Copyright (C) 1997-2025 Arthur de Jong and others\n"
               "This is free software; see the source for copying conditions.  There is NO\n"
               "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 }
@@ -134,6 +140,8 @@ static void display_usage(FILE *fp, const char *program_name)
   fprintf(fp, "  -c, --check        check if the daemon already is running\n");
   fprintf(fp, "  -d, --debug        don't fork and print debugging to stderr\n");
   fprintf(fp, "  -n, --nofork       don't fork\n");
+  fprintf(fp, "  -f, --config=FILE  alternative configuration file (default %s)\n", NSLCD_CONF_PATH);
+  fprintf(fp, "  -t, --test         test configuration for validity and exit\n");
   fprintf(fp, "      --help         display this help and exit\n");
   fprintf(fp, "      --version      output version information and exit\n");
   fprintf(fp, "\n" "Report bugs to <%s>.\n", PACKAGE_BUGREPORT);
@@ -141,14 +149,16 @@ static void display_usage(FILE *fp, const char *program_name)
 
 /* the definition of options for getopt(). see getopt(2) */
 static struct option const nslcd_options[] = {
-  {"check",   no_argument, NULL, 'c'},
-  {"debug",   no_argument, NULL, 'd'},
-  {"nofork",  no_argument, NULL, 'n'},
-  {"help",    no_argument, NULL, 'h'},
-  {"version", no_argument, NULL, 'V'},
-  {NULL,      0,           NULL, 0}
+  {"check",   no_argument,       NULL, 'c'},
+  {"debug",   no_argument,       NULL, 'd'},
+  {"nofork",  no_argument,       NULL, 'n'},
+  {"config",  required_argument, NULL, 'f'},
+  {"test",    no_argument,       NULL, 't'},
+  {"help",    no_argument,       NULL, 'h'},
+  {"version", no_argument,       NULL, 'V'},
+  {NULL,      0,                 NULL, 0}
 };
-#define NSLCD_OPTIONSTRING "cndhV"
+#define NSLCD_OPTIONSTRING "cndf:thV"
 
 /* parse command line options and save settings in struct  */
 static void parse_cmdline(int argc, char *argv[])
@@ -168,6 +178,17 @@ static void parse_cmdline(int argc, char *argv[])
       case 'n': /* -n, --nofork       don't fork */
         nslcd_nofork++;
         break;
+      case 'f': /* -f, --config=FILE  alternative configuration file */
+        nslcd_conf_path = strdup(optarg);
+        if (nslcd_conf_path == NULL)
+        {
+          log_log(LOG_CRIT, "strdup() failed to allocate memory");
+          exit(EXIT_FAILURE);
+        }
+        break;
+      case 't': /* -t, --test        test configuration for validity and exit */
+        nslcd_testconfig = 1;
+        break;
       case 'h': /*     --help         display this help and exit */
         display_usage(stdout, argv[0]);
         exit(EXIT_SUCCESS);
@@ -200,13 +221,6 @@ static void sig_handler(int signum)
 /* do some cleaning up before terminating */
 static void exithandler(void)
 {
-  /* close socket if it's still in use */
-  if (nslcd_serversocket >= 0)
-  {
-    if (close(nslcd_serversocket))
-      log_log(LOG_WARNING, "problem closing server socket (ignored): %s",
-              strerror(errno));
-  }
   /* remove existing named socket */
   if (unlink(NSLCD_SOCKET) < 0)
   {
@@ -721,7 +735,13 @@ int main(int argc, char *argv[])
   if (myldap_set_debuglevel(nslcd_debugging) != LDAP_SUCCESS)
     exit(EXIT_FAILURE);
   /* read configuration file */
-  cfg_init(NSLCD_CONF_PATH);
+  cfg_init(nslcd_conf_path);
+  /* exit if we only wanted to check the configuration */
+  if (nslcd_testconfig)
+  {
+    log_log(LOG_INFO, "config (%s) OK", nslcd_conf_path);
+    exit(EXIT_SUCCESS);
+  }
   /* set default mode for pidfile and socket */
   (void)umask((mode_t)0022);
   /* see if someone already locked the pidfile
@@ -891,7 +911,6 @@ int main(int argc, char *argv[])
               i, strerror(errno));
   /* close server socket to trigger failures in threads waiting on accept() */
   close(nslcd_serversocket);
-  nslcd_serversocket = -1;
   /* if we can, wait a few seconds for the threads to finish */
 #ifdef HAVE_PTHREAD_TIMEDJOIN_NP
   ts.tv_sec = time(NULL) + 3;
@@ -900,10 +919,16 @@ int main(int argc, char *argv[])
   for (i = 0; i < nslcd_cfg->threads; i++)
   {
 #ifdef HAVE_PTHREAD_TIMEDJOIN_NP
-    pthread_timedjoin_np(nslcd_threads[i], NULL, &ts);
-#endif /* HAVE_PTHREAD_TIMEDJOIN_NP */
+    if (pthread_timedjoin_np(nslcd_threads[i], NULL, &ts) == -1) {
+      if (errno != EBUSY)
+        log_log(LOG_ERR, "thread %d cannot be joined (ignoring): %s", i,
+                strerror(errno));
+      log_log(LOG_ERR, "thread %d is still running, shutting down anyway", i);
+    }
+#else
     if (pthread_kill(nslcd_threads[i], 0) == 0)
       log_log(LOG_ERR, "thread %d is still running, shutting down anyway", i);
+#endif /* HAVE_PTHREAD_TIMEDJOIN_NP */
   }
   /* we're done */
   return EXIT_SUCCESS;
